=========
Updatable
=========

Finds packages that require updates on a python environment

Installation
~~~~~~~~~~~~

The latest release of updatable can be installed via PyPI:

::

    pip install -U updatable


Usage
~~~~~~~~~~~

The package can be used as a command line tool, so you can get a list of all
packages that require updates from your current environment. You may also use
the package inside of your python application, to list the packages over a REST
endpoint, forward them by mail or other purpose.
